Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type MPIJobLister ¶
type MPIJobLister interface {
// List lists all MPIJobs in the indexer.
List(selector labels.Selector) (ret []*v1alpha1.MPIJob, err error)
// MPIJobs returns an object that can list and get MPIJobs.
MPIJobs(namespace string) MPIJobNamespaceLister
MPIJobListerExpansion
}
MPIJobLister helps list MPIJobs.
func NewMPIJobLister ¶
func NewMPIJobLister(indexer cache.Indexer) MPIJobLister
NewMPIJobLister returns a new MPIJobLister.
type MPIJobListerExpansion ¶
type MPIJobListerExpansion interface{}
MPIJobListerExpansion allows custom methods to be added to MPIJobLister.
type MPIJobNamespaceLister ¶
type MPIJobNamespaceLister interface {
// List lists all MPIJobs in the indexer for a given namespace.
List(selector labels.Selector) (ret []*v1alpha1.MPIJob, err error)
// Get retrieves the MPIJob from the indexer for a given namespace and name.
Get(name string) (*v1alpha1.MPIJob, error)
MPIJobNamespaceListerExpansion
}
MPIJobNamespaceLister helps list and get MPIJobs.
type MPIJobNamespaceListerExpansion ¶
type MPIJobNamespaceListerExpansion interface{}
MPIJobNamespaceListerExpansion allows custom methods to be added to MPIJobNamespaceLister.
Click to show internal directories.
Click to hide internal directories.